@@ -38,6 +38,7 @@ extern "C" {
 enum connman_network_type {
 	CONNMAN_NETWORK_TYPE_UNKNOWN       = 0,
 	CONNMAN_NETWORK_TYPE_WIFI          = 1,
+	CONNMAN_NETWORK_TYPE_WIMAX         = 2,
 	CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN = 8,
 	CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN = 9,
 	CONNMAN_NETWORK_TYPE_HSO           = 23,
@@ -57,6 +58,7 @@ extern struct connman_network *connman_network_create(const char *identifier,
 extern struct connman_network *connman_network_ref(struct connman_network *network);
 extern void connman_network_unref(struct connman_network *network);
 
+extern enum connman_network_type connman_network_get_type(struct connman_network *network);
 extern const char *connman_network_get_identifier(struct connman_network *network);
 
 extern const char *connman_network_get_path(struct connman_network *network);
@@ -66,10 +68,14 @@ extern int connman_network_get_index(struct connman_network *network);
 
 extern void connman_network_set_protocol(struct connman_network *network,
 					enum connman_network_protocol protocol);
+extern void connman_network_set_group(struct connman_network *network,
+							const char *group);
 
 extern int connman_network_set_available(struct connman_network *network,
 						connman_bool_t available);
 extern connman_bool_t connman_network_get_available(struct connman_network *network);
+extern int connman_network_set_associating(struct connman_network *network,
+						connman_bool_t associating);
 extern int connman_network_set_connected(struct connman_network *network,
 						connman_bool_t connected);
 extern connman_bool_t connman_network_get_connected(struct connman_network *network);
